# Meterviewer

Meter Data viewer, to view multiple dataset via notebook.

## Install

We use [pdm] to manage the project.

- To install pdm, run `python3 -m pip install pdm`.
- To install the dependencies, run `pdm install`.

## Documentation

We use [mkdocs](https://www.mkdocs.org/) for documentation.

- To install `mkdocs`, use `python3 -m pip install mkdocs`.
- To view the documentation, run `cd docs && mkdocs serve`.

## Notes

1. Pure functional is critial. Less things to worry about.


## For Developer

`pdm run pip install -r ./dev.txt`
